@@ -7,7 +7,7 @@ Components.utils.import('resource://indexdata/util/logging.js');
 var logger = logging.getLogger();
 
 
-/* The constructor takes a reference to an array of condidionts which will be
+/* The constructor takes a reference to an array of conditions which will be
  * updated in the draw() method and used to determine the output of
  * eval(). Each have the following properties: 
  *
@@ -315,7 +315,7 @@ Conditional.prototype.toString = function () {
   let str = Conditional.oneToString(this.conditions[0]);
   for (let i=1; i<this.conditions.length; i++) {
     let cur = this.conditions[i];
-    str += cur.connective === 'AND' ? ' && ' : ' || ';  
+    str += cur.connective === 'OR' ? ' || ' : ' && ';  
     str += Conditional.oneToString(cur);
   }
   return str; 
