@@ -218,6 +218,7 @@ var xmlHelper = {
         }
         return node;
     },
+    
     removeNode: function (node) {
         if (node.parentNode != null)
           node.parentNode.removeChild(node);
@@ -233,6 +234,16 @@ var xmlHelper = {
         }
     },
 
+    // Checks if a node is somehow descendening from the (grand)parent
+    isAncestor: function (node, parent) {
+        while(node) {
+            if ( node === parent )
+                return true;
+            node = node.parentNode;
+        }
+        return false;
+    },
+
     getElementXpath: function (target, truncate, nsList) {
       var doc = target.ownerDocument;
       /*
@@ -791,11 +802,13 @@ var xmlHelper = {
                                 // apply xpointer (only xpath1() subset is supported)
                                 var responseNodes;
                                 if (xpointer) {
+                                    // XPathResult.ORDERED_NODE_SNAPSHOT_TYPE was
+                                    // undefined so we use a literal 7
                                     var xpathResult = response.evaluate(
                                                                      xpointer,
                                                                      response,
                                                                      null,
-                                                                     XPathResult.ORDERED_NODE_SNAPSHOT_TYPE,
+                                                                     7,
                                                                      null
                                                                   );
                                     var a = [];
@@ -852,7 +865,7 @@ var xmlHelper = {
             // Delete in reverse order so shrinking .length does not prematurely end the loop
             for (i = xincludes.length-1; i >= 0; i--) {
                 logger.log(Level.DEBUG, "deleting XInclude node #" + (i+1) + " of " + xincludes.length);
-                xincludeParent.removeChild(xincludes[i]);
+                xincludes[i].parentNode.removeChild(xincludes[i]);
             }
         }
         return docu;
