@@ -30,7 +30,7 @@ do
     HASTESTCONNECTOR=""
   fi
   # Test connectors using the step
-  CONNCOUNT=`xmllint --format $CONNECTORS | grep -iw $BN | wc -l`
+  CONNCOUNT=`xmllint --format $CONNECTORS | grep -iw step.name=.$BN. | wc -l`
   if [ $CONNCOUNT == "0" ]
   then 
     USEDINTESTS=""
@@ -43,4 +43,4 @@ do
     SUMMARY="NO TESTS AT ALL"
   fi
   echo $BN: $SUMMARY
-done
\ No newline at end of file
+done
