@@ -13,21 +13,26 @@ case `uname` in
 	* ) export CF_APP_PATH=`pwd` ;;
 esac
 
+
 echo "running regression in $DIR"
+if ! zoomsh "quit"
+then
+  echo "No zoomsh found on PATH"
+  echo "(install yaz?)"
+  exit 1
+fi
+
 CF_DISPLAY_LOCK=/tmp/cf-xvfb \
    ./cf-zserver -l cf-zserver.log unix:socket -p cf-zserver.pid -D
 test $? -ne 0 && (echo "Could not start cf-zserver"; echo "You may need to run: killall cf-zserver lt-metaproxy"; exit 1)
 : ${diff_opt="-u"}
 : ${REGRESSION_FATAL=false}
-
+: ${MAKE_OUT=false}
 
 GRET=0
 error () {
     $REGRESSION_FATAL && exit 1
-
-    plus=$1
-    test -n "$plus" || plus=1   
-    GRET=`expr $GRET + $plus`
+    GRET=1
 }
 
 if [ ! -z $CONNECTORS ]
@@ -79,10 +84,14 @@ do
             # exit 1
             # We can *either* kill the cf-zserver and exit, *or* set error
 	    echo "  $CNAME: differ"
-            error 1
+            error
 	else
 	    echo "  $CNAME: OK"
 	fi
+    elif $MAKE_OUT; then
+	echo " $CNAME: Making first time"
+        cp $LOG $DIR/$CNAME.out
+        error
     else
         kill `cat cf-zserver.pid`
         rm -f cf-zserver.pid
@@ -92,7 +101,7 @@ do
         echo "  And add it to git with "
         echo "    cd $DIR; git add $CONNECTOR.out"
         echo "  (make sure the .query file is in git too!)"
-        error 1
+        error
     fi    
   
 done # connector loop
