@@ -6,7 +6,7 @@
 
 unset CF_BASE_PATH
 export CF_MODULE_PATH=`cd ../../builder/modules; pwd`
-export CF_REPO_AUTH_URL=http://cfrepo.indexdata.com/auth.pl
+export CF_REPO_AUTH_URL=http://cfrepo.indexdata.com/auth.xml
 export CF_REPO_FETCH_URL=http://cfrepo.indexdata.com/repo.pl/%s.cf
 export CF_APP_PATH=`pwd`
 
