@@ -49,7 +49,7 @@ struct session : CF_Logger
     int log_fd;
     int no_searches;
     CF_Metadata metadata;
-    void printf(const char *level, const char *fmt, ...);
+    void printf(const char *module, int level, const char *fmt, ...);
 };
 
 /** Z39.50 session ptr. */
@@ -63,7 +63,7 @@ struct serverinfo
 };
 
 
-void session::printf(const char *level, const char *fmt, ...)
+void session::printf(const char *module, int level, const char *fmt, ...)
 {
     va_list ap;
     char buf[4096];
@@ -81,7 +81,7 @@ void session::printf(const char *level, const char *fmt, ...)
             fflush(engine_log);
         }
         else
-            yaz_log(YLOG_LOG, "%s %s", level, buf);
+            yaz_log(level, "%s %s", module, buf);
     }
 
     va_end(ap);
@@ -200,7 +200,7 @@ static void connector_open(sessionhandle ses, bend_search_rr *rr)
                                                               proxy,
                                                               loglevel,
                                                               ses,
-                                                              ses->log_fd);
+                                                              ses->log_fd, 1);
         }
         catch (CF_Engine_Error &e) {
             rr->errcode = YAZ_BIB1_TEMPORARY_SYSTEM_ERROR;
